import React, { useRef } from 'react';
import { history, Link } from 'umi';
import { Button, Popconfirm, message } from 'antd';
import { PlusOutlined } from '@ant-design/icons';
import { getCooperativeList, deleteCooperative } from '@/services/cooperative';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import PageTable from '@/components/PageTable';

export default (props) => {
  const actionRef = useRef();
  const actions = () => [
    <Button key="add" type="primary" icon={<PlusOutlined />} onClick={() => gotoEdit()}>
      新增机构
    </Button>,
  ];
  const gotoEdit = () => {
    history.push(`./Cooperative/edit.jsx`);
  };
  const handleDelete = (val) => {
    deleteCooperative(val)
      .then((res) => {
        message.success('删除成功');
        actionRef.current.reload();
      })
      .catch((err) => {
        return {
          success: false,
        };
      });
  };
  const columns = [
    {
      title: '机构名',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: '联系人',
      dataIndex: 'contactPerson',
      key: 'contactPerson',
    },
    {
      title: '联系方式',
      dataIndex: 'phone',
      key: 'phone',
    },
    {
      title: '区域',
      dataIndex: 'regionId',
      key: 'regionId',
    },
    {
      title: '地址',
      dataIndex: 'address',
      key: 'address',
      search: false,
    },

    {
      title: '农机数',
      dataIndex: 'machineryNum',
      key: 'machineryNum',
      search: false,
      render: (_, record) => record.machineryNum || 0,
    },
    {
      title: '员工数',
      dataIndex: 'employeesNum',
      key: 'employeesNum',
      search: false,
      render: (_, record) => record.employeesNum || 0,
    },
    {
      title: '完成订单数',
      dataIndex: 'orderNum',
      key: 'orderNum',
      search: false,
      render: (_, record) => record.orderNum || 0,
    },
    {
      title: '评分',
      dataIndex: 'score',
      key: 'score',
      search: false,
      render: (_, record) => record.score || 0,
    },
    {
      title: '操作',
      valueType: 'option',
      render: (_, record) => [
        <Link key={1} to={`./Cooperative/edit.jsx?id=${record.orgId}`}>
          编辑
        </Link>,
        <Popconfirm
          key={2}
          title="您是否确认删除 ?"
          onConfirm={() => handleDelete(record.orgId)}
          okText="确定"
          cancelText="取消"
        >
          <a href="#">删除</a>
        </Popconfirm>,
      ],
    },
  ];

  return (
    <PageHeaderWrapper>
      <PageTable
        request={getCooperativeList}
        // expfunc={exportPersonList}
        columns={columns}
        rowKey="orgId"
        options={false}
        toolBarRender={actions}
        actionRef={actionRef}
        scroll={{ x: 2000 }}
      />
    </PageHeaderWrapper>
  );
};
